import { Card, CardContent } from "@/components/ui/card"
import Link from "next/link"
import { ChevronRight, Home, Briefcase, Car, ShoppingBag, Wrench } from "lucide-react"

export default function TaskCategories() {
  const categories = [
    {
      id: "house",
      name: "Бытовые услуги",
      icon: <Home className="h-6 w-6" />,
      subcategories: [
        { id: "cleaning", name: "Уборка" },
        { id: "windowswashing", name: "Мытье окон" },
        { id: "repair", name: "Ремонт и строительство" },
      ],
    },
    {
      id: "business",
      name: "Бизнес услуги",
      icon: <Briefcase className="h-6 w-6" />,
      subcategories: [
        { id: "marketing", name: "Маркетинг" },
        { id: "legal", name: "Юридические услуги" },
      ],
    },
    {
      id: "transport",
      name: "Перевозки",
      icon: <Car className="h-6 w-6" />,
      subcategories: [
        { id: "delivery", name: "Доставка" },
        { id: "moving", name: "Переезд" },
      ],
    },
    {
      id: "shopping",
      name: "Покупки",
      icon: <ShoppingBag className="h-6 w-6" />,
      subcategories: [
        { id: "products", name: "Продукты" },
        { id: "clothes", name: "Одежда" },
      ],
    },
    {
      id: "repair",
      name: "Ремонт техники",
      icon: <Wrench className="h-6 w-6" />,
      subcategories: [
        { id: "computer", name: "Компьютеры" },
        { id: "appliances", name: "Бытовая техника" },
      ],
    },
  ]

  return (
    <div className="container mx-auto px-4 py-8">
      <div className="mb-8">
        <h1 className="text-2xl font-bold">Выберите категорию задания</h1>
        <p className="text-muted-foreground">Шаг 1 из 4</p>
      </div>

      <div className="grid gap-4 md:grid-cols-2 lg:grid-cols-3">
        {categories.map((category) => (
          <Card key={category.id} className="overflow-hidden">
            <CardContent className="p-0">
              <div className="p-4 flex items-center gap-3">
                <div className="flex h-10 w-10 items-center justify-center rounded-full bg-muted">{category.icon}</div>
                <h3 className="font-medium">{category.name}</h3>
              </div>
              <div className="border-t">
                {category.subcategories.map((subcategory) => (
                  <Link
                    key={subcategory.id}
                    href={`/tasks/new/${category.id}/${subcategory.id}`}
                    className="flex items-center justify-between p-4 hover:bg-muted transition-colors"
                  >
                    <span>{subcategory.name}</span>
                    <ChevronRight className="h-4 w-4 text-muted-foreground" />
                  </Link>
                ))}
              </div>
            </CardContent>
          </Card>
        ))}
      </div>
    </div>
  )
}
